@@ -16,7 +16,7 @@ Usage::
     session_client: IoTEventsClient = session.client("iotevents")
     ```
 """
-from mypy_boto3_iotevents.client import IoTEventsClient
+from .client import IoTEventsClient
 
 Client = IoTEventsClient
 
